==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/config/routes.rb <==
ActionController::Routing::Routes.draw do |map|
  map.resources :csv_file_upload_history

  map.resources :banner_conditions

  map.resources :banner_displays

  map.resources :roles, :controller => 'goldberg/roles', :path_prefix => '/goldberg'

  map.resources :banners

  map.resources :product_prices

  map.resources :user_ranks

  map.resources :product_components

  map.resources :product_groups

  map.resources :campaign_target_product_skus, :collection=>{:names=>:get}

  map.resources :campaign_effects, :collection=>{:names=>:get}

  map.resources :campaign_conditions, :collection=>{:names=>:get}

  map.resources :campaigns, :collection=>{:names=>:get}

  map.resources :product_images

  map.resources :product_skus, :member => {:edit => :post, :show => :any, :update => :post}

  map.resources :product_variation_items

  map.resources :product_variations

  map.resources :product_categories

  map.resources :discounts

  map.resources :product_displays, :collection => {:bulk_update_product_id => :post}, :member => {:edit => :post}

  #map.resources :countries

  map.resources :ms_shop_settings, :collection => {:init_index => :get}

  map.resources :cms_files

  map.resources :cms_layouts

  map.resources :cms_pages, :member => {:preview => :get, :undo_destroy => :delete},
    :collection => {:setup => :get, :tag_reference => :get}, :new => {:new_bind => :get}

  map.resources :cms_projects, :new => {:new_assign => :get}

  map.resources :cms_templates

  map.resources :cms_project_approvals

  map.resources :csv_file_download, :collection => {:index => :get}

  map.resources :csv_file_download_history

  #map.resources :csv_file_upload
  # The priority is based upon order of creation: first created -> highest priority.

  # Sample of regular route:
  # map.connect 'products/:id', :controller => 'catalog', :action => 'view'
  # Keep in mind you can assign values other than :controller and :action

  # Sample of named route:
  # map.purchase 'products/:id/purchase', :controller => 'catalog', :action => 'purchase'
  # This route can be invoked with purchase_url(:id => product.id)

  # You can have the root of your site routed by hooking up ''
  # -- just remember to delete public/index.html.
  map.connect '', :controller => "goldberg/auth", :action=> 'login'

  # Allow downloading Web Service WSDL as a file with an extension
  # instead of a file named 'wsdl'
  map.connect ':controller/service.wsdl', :action => 'wsdl'

  # Install the default route as the lowest priority.
  map.connect ':controller/:action/:id.:format'
  map.connect ':controller/:action/:id'

  #map.connect '*page_name', :controller => "goldberg/permissions", :action => "view"
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/config/routes.rb <==
ActionController::Routing::Routes.draw do |map|
  map.resources :csv_file_upload_history

  map.resources :banner_conditions

  map.resources :banner_displays

  map.resources :roles, :controller => 'goldberg/roles', :path_prefix => '/goldberg'

  map.resources :banners

  map.resources :product_prices

  map.resources :user_ranks

  map.resources :product_groups

  map.resources :campaign_target_product_skus, :collection=>{:names=>:get}

  map.resources :campaign_effects, :collection=>{:names=>:get}

  map.resources :campaign_conditions, :collection=>{:names=>:get}

  map.resources :campaigns, :collection=>{:names=>:get}

  map.resources :product_images

  map.resources :product_skus, :member => {:edit => :post, :show => :any, :update => :post}

  map.resources :product_variation_items

  map.resources :product_variations

  map.resources :product_categories

  map.resources :discounts

  map.resources :product_displays, :collection => {:bulk_update_product_id => :post}, :member => {:edit => :post}

  #map.resources :countries

  map.resources :ms_shop_settings, :collection => {:init_index => :get}

  map.resources :cms_files

  map.resources :cms_layouts

  map.resources :cms_pages, :member => {:preview => :get, :undo_destroy => :delete},
    :collection => {:setup => :get}, :new => {:new_bind => :get}

  map.resources :cms_projects, :new => {:new_assign => :get}

  map.resources :cms_templates

  map.resources :cms_project_approvals

  map.resources :csv_file_download, :collection => {:index => :get}

  map.resources :csv_file_download_history

  map.resources :tag_references, :collection => {:tag_reference => :get}

  #map.resources :csv_file_upload
  # The priority is based upon order of creation: first created -> highest priority.

  # Sample of regular route:
  # map.connect 'products/:id', :controller => 'catalog', :action => 'view'
  # Keep in mind you can assign values other than :controller and :action

  # Sample of named route:
  # map.purchase 'products/:id/purchase', :controller => 'catalog', :action => 'purchase'
  # This route can be invoked with purchase_url(:id => product.id)

  # You can have the root of your site routed by hooking up ''
  # -- just remember to delete public/index.html.
  map.connect '', :controller => "goldberg/auth", :action=> 'login'

  # Allow downloading Web Service WSDL as a file with an extension
  # instead of a file named 'wsdl'
  map.connect ':controller/service.wsdl', :action => 'wsdl'

  # Install the default route as the lowest priority.
  map.connect ':controller/:action/:id.:format'
  map.connect ':controller/:action/:id'

  #map.connect '*page_name', :controller => "goldberg/permissions", :action => "view"
end
